local assets =
{
	Asset("ANIM", "anim/bread.zip"),
	Asset("ANIM", "anim/bun.zip"),
	Asset("ANIM", "anim/items_ground.zip"),
	
	Asset("ATLAS", "images/inventoryimages/bread.xml"),
	Asset("ATLAS", "images/inventoryimages/bun.xml"),
	Asset("IMAGE", "images/water_images.tex"),
    Asset("ATLAS", "images/water_images.xml"),
}

local prefabs = 
{
	"spoiled_food",
}

local function bread()
	local inst = CreateEntity()
	inst.entity:AddTransform()
	inst.entity:AddAnimState()
	--
	
	MakeInventoryPhysics(inst)
	MakeSmallBurnable(inst)
	MakeSmallPropagator(inst)
	
	inst.AnimState:SetBank("bread")
	inst.AnimState:SetBuild("bread")
	inst.AnimState:PlayAnimation("idle")
	
	inst:AddTag("preparedfood")
    
	if not TheWorld.ismastersim then
		return inst
	end
		
	--
	
	inst:AddComponent("edible")
	inst.components.edible.foodtype = "VEGGIE"
	inst.components.edible.foodstate = "PREPARED"
	inst.components.edible.healthvalue = 5
	inst.components.edible.hungervalue = 45
	inst.components.edible.sanityvalue = 0

	inst:AddComponent("inspectable")

	inst:AddComponent("inventoryitem")
	inst.components.inventoryitem.atlasname = "images/inventoryimages/bread.xml"

	inst:AddComponent("stackable")
	inst.components.stackable.maxsize = TUNING.STACK_SIZE_SMALLITEM

	inst:AddComponent("perishable")
	inst.components.perishable:SetPerishTime(TUNING.PERISH_MED)
	inst.components.perishable:StartPerishing()
	inst.components.perishable.onperishreplacement = "spoiled_food"
	
	return inst
end

local function bun()
	local inst = CreateEntity()
	inst.entity:AddTransform()
	inst.entity:AddAnimState()
	--
	
	MakeInventoryPhysics(inst)
	MakeSmallBurnable(inst)
	MakeSmallPropagator(inst)
	
	inst.AnimState:SetBank("bun")
	inst.AnimState:SetBuild("bun")
	inst.AnimState:PlayAnimation("idle")
	
	inst:AddTag("preparedfood")
    
	if not TheWorld.ismastersim then
		return inst
	end
		
	--
	
	inst:AddComponent("edible")
	inst.components.edible.foodtype = "VEGGIE"
	inst.components.edible.foodstate = "PREPARED"
	inst.components.edible.healthvalue = 7
	inst.components.edible.hungervalue = 18
	inst.components.edible.sanityvalue = 7

	inst:AddComponent("inspectable")

	inst:AddComponent("inventoryitem")
	inst.components.inventoryitem.atlasname = "images/inventoryimages/bun.xml"

	inst:AddComponent("stackable")
	inst.components.stackable.maxsize = TUNING.STACK_SIZE_SMALLITEM

	inst:AddComponent("perishable")
	inst.components.perishable:SetPerishTime(TUNING.PERISH_MED)
	inst.components.perishable:StartPerishing()
	inst.components.perishable.onperishreplacement = "spoiled_food"
	
	return inst
end

local function flour()
    local inst = CreateEntity()

    inst.entity:AddTransform()
    inst.entity:AddAnimState()
    inst.entity:AddSoundEmitter()
    --

    MakeInventoryPhysics(inst)	

    inst.AnimState:SetBuild("items_ground")
    inst.AnimState:SetBank("items_ground")
    inst.AnimState:PlayAnimation("flour")

    --

--
	
	inst:AddComponent("stackable")
    inst.components.stackable.maxsize = TUNING.STACK_SIZE_SMALLITEM

    inst:AddComponent("inspectable")
	
	inst:AddComponent("tradable")

    inst:AddTag("show_spoilage")

    inst:AddComponent("inventoryitem")
    inst.components.inventoryitem.atlasname = "images/water_images.xml"
	inst.replica.inventoryitem:SetImage("flour")
	
	inst:AddComponent("perishable")
	inst.components.perishable:SetPerishTime(TUNING.PERISH_MED*2)
	inst.components.perishable:StartPerishing()
	inst.components.perishable.onperishreplacement = "spoiled_food"

    --

    return inst
end


return  Prefab( "common/inventory/bread", bread, assets, prefabs ),
		Prefab( "common/inventory/bun", bun, assets, prefabs ),
		Prefab( "common/inventory/flour", flour, assets, prefabs )